from ..model import User, Category, Forum, Board, Post, Thread
from ..util import sanitize_title

import json
import os

def output (data, destination):
    if isinstance(data, Forum):
        output_forum(data, destination)
    elif isinstance(data, Board):
        output_board(data, destination)
    elif isinstance(data, Thread):
        output_thread(data, destination)

def output_forum (data, destination):
    os.makedirs(destination)

    with open(os.path.join(destination, "index.json"), "w") as out_file:
        out_file.write(json.dumps({title: data.title}, indent=4))

    for category in data.categories:
        os.makedirs(os.path.join(destination, category.title))
        for board in category.children:
            output_board(board, os.path.join(destination, category.title, sanitize_title(board.title)))

def output_board (data, destination):
    os.makedirs(destination)
    os.makedirs(os.path.join(destination, "threads"))
    with open(os.path.join(destination, "index.json"), "w") as out_file:
        out_file.write(json.dumps({
            "title": data.title,
            "description": data.description
        }, indent=4))

    for thread in data.children:
        output_thread(thread, os.path.join(destination, "threads", sanitize_title(thread.title)))

def output_thread (data, destination):
    with open(destination, "w") as out_file:
        out_file.write(json.dumps(data, default=vars, indent=4))
